<?php
//=====================================================//
//
// ! YABDAB - GOOGLE SHEET CLASS v.3.0.8
// - MODIFIED: [ 2021-08-17 03:10:37 PM (Mike Yrabedra) ]
// - author: Mike Yrabedra
// - (c)2011-2021 Yabdab Inc. All rights reserved.
//=====================================================//

// show errors
//error_reporting(~0);
//ini_set('display_errors', 1);

require_once dirname(__FILE__) . DIRECTORY_SEPARATOR . "vendor/autoload.php";

define(
  "KEY_FILE",
  dirname(__FILE__) .
    DIRECTORY_SEPARATOR .
    "rw-formloom3-plugin-e73f0b371246.json"
);

class Spreadsheet
{
  // The file ID was copied from a URL while editing the sheet in Chrome
  private $file_id;

  public function __construct($file_id)
  {
    $this->file_id = $file_id;
  }

  function add($ary_values = [])
  {
    // Set up the API
    $client = new Google_Client();
    $client->setAuthConfig(KEY_FILE);
    $client->addScope(Google_Service_Sheets::SPREADSHEETS);
    $client->setApplicationName("Formsnap/Formloom");

    //$accessToken = 'ACCESS_TOKEN'; // Use your generated access token
    //$client->setAccessToken($accessToken);
    $sheet_service = new Google_Service_Sheets($client);

    // Set the sheet ID
    $fileId = $this->file_id; // Copy & paste from a spreadsheet URL
    
    // Get first row that should have headers
    $response = $sheet_service->spreadsheets_values->get($fileId, "1:1"); // 1:1 gets first row (headers)
    $headers = $response->getValues();
    
    // build new array in the correct order
    $append=[];
    foreach($headers[0] as $col){
      if(isset($ary_values[$col])){
        array_push($append, $ary_values[$col]);
      }else{
        array_push($append, "");
      }
    }
    
    // Build the CellData array
    $values = [];
    foreach ($append as $v) {
      $cellData = new Google_Service_Sheets_CellData();
      $value = new Google_Service_Sheets_ExtendedValue();
      $value->setStringValue($v);
      $cellData->setUserEnteredValue($value);
      $values[] = $cellData;
    }
    
    // Build the RowData
    $rowData = new Google_Service_Sheets_RowData();
    $rowData->setValues($values);

    // Prepare the request
    $append_request = new Google_Service_Sheets_AppendCellsRequest();
    $append_request->setSheetId(0);
    $append_request->setRows($rowData);
    $append_request->setFields("userEnteredValue");

    // Set the request
    $request = new Google_Service_Sheets_Request();
    $request->setAppendCells($append_request);

    // Add the request to the requests array
    $requests = [];
    $requests[] = $request;

    // Prepare the update
    $batchUpdateRequest = new Google_Service_Sheets_BatchUpdateSpreadsheetRequest(
      [
        "requests" => $requests,
      ]
    );

    try {
      // Execute the request
      $response = $sheet_service->spreadsheets->batchUpdate(
        $fileId,
        $batchUpdateRequest
      );
      if ($response->valid()) {
        // Success, the row has been added
        return true;
      }
    } catch (Exception $e) {
      // Something went wrong
      echo $e->getMessage();
    }

    return false;
  }
}
